@@ -10,8 +10,6 @@
 use strict;
 use warnings;
 
-use Mail::DKIM::PrivateKey;
-
 package Mail::DKIM::Algorithm::rsa_sha256;
 use base "Mail::DKIM::Algorithm::Base";
 use Carp;
@@ -24,14 +22,7 @@ sub init_digests
 
 	# initialize a SHA-256 Digest
 	$self->{header_digest} = new Digest::SHA(256);
-	if ($self->{draft_version} eq "01")
-	{
-		$self->{body_digest} = new Digest::SHA(256);
-	}
-	else
-	{
-		$self->{body_digest} = $self->{header_digest};
-	}
+	$self->{body_digest} = new Digest::SHA(256);
 }
 
 sub sign
