@@ -10,12 +10,12 @@
 use strict;
 use warnings;
 
-use Mail::DKIM::Signature;
+use Mail::Address;
 
 package Mail::DKIM::Common;
 use base "Mail::DKIM::MessageParser";
 use Carp;
-our $VERSION = 0.38;
+our $VERSION = 0.40;
 
 sub new
 {
